http

package
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 29, 2026 License: AGPL-3.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type InaraClient

type InaraClient struct {
	// contains filtered or unexported fields
}

func NewInaraClient

func NewInaraClient(client *http.Client) *InaraClient

func (*InaraClient) Do

func (c *InaraClient) Do(ctx context.Context) (string, error)

Do executes a request to Inara using the URL specified in config.URL. returns the HTML (if any).

type XpathParser

type XpathParser struct{}

func NewXPathParser

func NewXPathParser() *XpathParser

func (*XpathParser) Parse

func (xp *XpathParser) Parse(inputHTML string) (int, error)

Parse attempts to parse an input html using the xpath expression in config.XPath. if an number is found in the target path it returns it. If multiple are found it returns the first.

Jump to